ConfigOptionUpdate class

Session configuration options updated.

Constructors

ConfigOptionUpdate({List<SessionConfigOption> configOptions = const [], Map<String, Object?>? meta})
const
ConfigOptionUpdate.fromJson(Map<String, Object?> json)
factory

Properties

configOptions List<SessionConfigOption>
final
hashCode int
The hash code for this object.
no setterinherited
meta Map<String, Object?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited