PermissionOption class

A permission option presented to the user.

Constructors

PermissionOption({required String optionId, required String name, required PermissionOptionKind kind, Map<String, Object?>? meta})
const
PermissionOption.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
kind PermissionOptionKind
final
meta Map<String, Object?>
final
name String
final
optionId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited