SessionConfigOptionsCapabilities class

Client session config-options capability.

Properties

boolean → BooleanConfigOptionCapabilities?
final
hashCode → int
The hash code for this object.
no setterinherited
meta → Map<String, Object?>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited