SessionConfigUngroupedOptions class final

A flat list of options.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
options → List<SessionConfigSelectOption>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → List<Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited