ToolCallUpdate class
A partial update to an existing tool call.
All fields except toolCallId are optional — only changed fields are sent.
Constructors
-
ToolCallUpdate({required String toolCallId, ToolKind? kind, ToolCallStatus? status, String? title, List<
ToolCallContent> ? content, List<ToolCallLocation> ? locations, Object? rawInput, Object? rawOutput, Map<String, Object?> ? meta}) -
const
-
ToolCallUpdate.fromJson(Map<
String, Object?> json) -
factory
Properties
-
content
→ List<
ToolCallContent> ? -
Replacement content when present.
nullmeans the field was omitted; an empty list explicitly clears the current content.final - hashCode → int
-
The hash code for this object.
no setterinherited
- kind → ToolKind?
-
final
-
locations
→ List<
ToolCallLocation> ? -
Replacement locations when present.
nullmeans the field was omitted; an empty list explicitly clears the current locations.final -
meta
→ Map<
String, Object?> -
final
- rawInput → Object?
-
final
- rawOutput → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ToolCallStatus?
-
final
- title → String?
-
final
- toolCallId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited